



import Highlight from "@tiptap/extension-highlight";
import TextAlign from "@tiptap/extension-text-align";
import { EditorContent, useEditor } from "@tiptap/react";
import StarterKit from "@tiptap/starter-kit";
import './app.scss';
import Iframe from "./extensions/Iframe";
// import "./styles.css";

const MenuBar = ({ editor }: any) => {
    if (!editor) {
        return null;
    }

    return (
        <div className="menuBar">
            <button
                onClick={() => editor.chain().focus().toggleHeading({ level: 1 }).run()}
                className={editor.isActive("heading", { level: 1 }) ? "is-active" : ""}
            >
                h1
            </button>
            <button
                onClick={() => editor.chain().focus().toggleHeading({ level: 2 }).run()}
                className={editor.isActive("heading", { level: 2 }) ? "is-active" : ""}
            >
                h2
            </button>
            <button
                onClick={() => editor.chain().focus().toggleHeading({ level: 3 }).run()}
                className={editor.isActive("heading", { level: 3 }) ? "is-active" : ""}
            >
                h3
            </button>
            <button
                onClick={() => editor.chain().focus().setParagraph().run()}
                className={editor.isActive("paragraph") ? "is-active" : ""}
            >
                paragraph
            </button>
            <button
                onClick={() => editor.chain().focus().toggleBold().run()}
                className={editor.isActive("bold") ? "is-active" : ""}
            >
                bold
            </button>
            <button
                onClick={() => editor.chain().focus().toggleItalic().run()}
                className={editor.isActive("italic") ? "is-active" : ""}
            >
                italic
            </button>
            <button
                onClick={() => editor.chain().focus().toggleStrike().run()}
                className={editor.isActive("strike") ? "is-active" : ""}
            >
                strike
            </button>
            <button onClick={() => editor.chain().focus().toggleHighlight().run()} className={editor.isActive('highlight') ? 'is-active' : ''}>
                highlight
            </button>
            <button
                onClick={() => editor.chain().focus().setTextAlign("left").run()}
                className={editor.isActive({ textAlign: "left" }) ? "is-active" : ""}
            >
                left
            </button>
            <button
                onClick={() => editor.chain().focus().setTextAlign("center").run()}
                className={editor.isActive({ textAlign: "center" }) ? "is-active" : ""}
            >
                center
            </button>
            <button
                onClick={() => editor.chain().focus().setTextAlign("right").run()}
                className={editor.isActive({ textAlign: "right" }) ? "is-active" : ""}
            >
                right
            </button>
            <button
                onClick={() => editor.chain().focus().setTextAlign("justify").run()}
                className={editor.isActive({ textAlign: "justify" }) ? "is-active" : ""}
            >
                justify
            </button>
            <button
                onClick={() => openModal(editor)}
            // className={editor.isActive("mark") ? "is-active" : ""}
            >
                Mark
            </button>
        </div>
    );
};

const openModal = (editor: any) => {
    console.log("OPEN");


    editor.chain().focus()
        .setIframe({ src: "https://www.openstreetmap.org/export/embed.html?bbox=-0.004017949104309083%2C51.47612752641776%2C0.00030577182769775396%2C51.478569861898606&layer=mapnik" })
        .run()
}

type EditorProps = {
    className?: string;
    html: string;
    setHtml: any;
};


export function Editor({ className, html, setHtml }: EditorProps) {
    const editor = useEditor({
        onUpdate({ editor }: any) {
            setHtml(editor.getHTML())
        },
        extensions: [
            StarterKit,
            TextAlign.configure({
                types: ["heading", "paragraph"]
            }),
            Highlight,
            Iframe
        ],
        content: html
    });



    return (
        <div className={`lidiaEditor ${className}`}>

            <MenuBar
                editor={editor} />


            <div className="editorContainer">
                <EditorContent
                    className="editor"
                    editor={editor} />
            </div>
        </div>
    );
}